from .async_client import (
    IdentityVerificationServiceAsyncClient as IdentityVerificationServiceAsyncClient,
)
from .client import (
    IdentityVerificationServiceClient as IdentityVerificationServiceClient,
)

__all__ = [
    "IdentityVerificationServiceClient",
    "IdentityVerificationServiceAsyncClient",
]
