from .async_client import (
    CustomerNegativeCriterionServiceAsyncClient as CustomerNegativeCriterionServiceAsyncClient,
)
from .client import (
    CustomerNegativeCriterionServiceClient as CustomerNegativeCriterionServiceClient,
)

__all__ = [
    "CustomerNegativeCriterionServiceClient",
    "CustomerNegativeCriterionServiceAsyncClient",
]
