from .async_client import (
    ConversionGoalCampaignConfigServiceAsyncClient as ConversionGoalCampaignConfigServiceAsyncClient,
)
from .client import (
    ConversionGoalCampaignConfigServiceClient as ConversionGoalCampaignConfigServiceClient,
)

__all__ = [
    "ConversionGoalCampaignConfigServiceClient",
    "ConversionGoalCampaignConfigServiceAsyncClient",
]
