from .async_client import (
    BiddingStrategyServiceAsyncClient as BiddingStrategyServiceAsyncClient,
)
from .client import BiddingStrategyServiceClient as BiddingStrategyServiceClient

__all__ = ["BiddingStrategyServiceClient", "BiddingStrategyServiceAsyncClient"]
