from .async_client import (
    CustomizerAttributeServiceAsyncClient as CustomizerAttributeServiceAsyncClient,
)
from .client import CustomizerAttributeServiceClient as CustomizerAttributeServiceClient

__all__ = ["CustomizerAttributeServiceClient", "CustomizerAttributeServiceAsyncClient"]
