from .async_client import (
    TravelAssetSuggestionServiceAsyncClient as TravelAssetSuggestionServiceAsyncClient,
)
from .client import (
    TravelAssetSuggestionServiceClient as TravelAssetSuggestionServiceClient,
)

__all__ = [
    "TravelAssetSuggestionServiceClient",
    "TravelAssetSuggestionServiceAsyncClient",
]
