from .async_client import (
    CampaignConversionGoalServiceAsyncClient as CampaignConversionGoalServiceAsyncClient,
)
from .client import (
    CampaignConversionGoalServiceClient as CampaignConversionGoalServiceClient,
)

__all__ = [
    "CampaignConversionGoalServiceClient",
    "CampaignConversionGoalServiceAsyncClient",
]
