from .async_client import (
    AutomaticallyCreatedAssetRemovalServiceAsyncClient as AutomaticallyCreatedAssetRemovalServiceAsyncClient,
)
from .client import (
    AutomaticallyCreatedAssetRemovalServiceClient as AutomaticallyCreatedAssetRemovalServiceClient,
)

__all__ = [
    "AutomaticallyCreatedAssetRemovalServiceClient",
    "AutomaticallyCreatedAssetRemovalServiceAsyncClient",
]
